@@ -32,7 +32,6 @@ import io
 
 import numpy as np
 from packaging.version import Version
-from xarray import Dataset
 from xarray.backends import NetCDF4DataStore
 from xarray.backends.common import (
     AbstractDataStore,
@@ -175,6 +174,9 @@ class RadolanDataStore(AbstractDataStore):
 class RadolanBackendEntrypoint(BackendEntrypoint):
     """Xarray BackendEntrypoint for RADOLAN data."""
 
+    description = "Open RADOLAN in Xarray"
+    url = "https://docs.wradlib.org/en/stable/notebooks/fileio/wradlib_radolan_backend.html"
+
     def open_dataset(
         self,
         filename_or_obj,
@@ -488,6 +490,11 @@ class OdimBackendEntrypoint(BackendEntrypoint):
     """Xarray BackendEntrypoint for ODIM data."""
 
     available = has_import(h5netcdf)
+    description = "Open ODIM_H5 (.h5, .hdf5) using h5netcdf in Xarray"
+    url = (
+        "https://docs.wradlib.org/en/stable/notebooks/fileio/wradlib_odim_backend.html"
+    )
+    name = "wradlib-odim"
 
     def open_dataset(
         self,
@@ -670,6 +677,11 @@ class GamicBackendEntrypoint(BackendEntrypoint):
     """Xarray BackendEntrypoint for GAMIC data."""
 
     available = has_import(h5netcdf)
+    description = "Open GAMIC HDF5 (.h5, .hdf5, .mvol) using h5netcdf in Xarray"
+    url = (
+        "https://docs.wradlib.org/en/stable/notebooks/fileio/wradlib_gamic_backend.html"
+    )
+    name = "wradlib-gamic"
 
     def open_dataset(
         self,
@@ -738,6 +750,9 @@ class CfRadial1BackendEntrypoint(BackendEntrypoint):
     """Xarray BackendEntrypoint for CfRadial1 data."""
 
     available = has_import(netCDF4)
+    description = "Open CfRadial1 (.nc, .nc4) using netCDF4 in Xarray"
+    url = "https://docs.wradlib.org/en/stable/notebooks/fileio/wradlib_cfradial1_backend.html"
+    name = "wradlib-cfradial1"
 
     def open_dataset(
         self,
@@ -783,6 +798,9 @@ class CfRadial2BackendEntrypoint(BackendEntrypoint):
     """Xarray BackendEntrypoint for CfRadial2 data."""
 
     available = has_import(netCDF4)
+    description = "Open CfRadial2 (.nc, .nc4) using netCDF4 in Xarray"
+    url = "https://docs.wradlib.org/en/stable/notebooks/fileio/wradlib_cfradial2_backend.html"
+    name = "wradlib-cfradial2"
 
     def open_dataset(
         self,
@@ -798,61 +816,31 @@ class CfRadial2BackendEntrypoint(BackendEntrypoint):
         format=None,
         group=None,
     ):
-
-        # 1. first open store with group=None
-        # to get the root group and select wanted sweep/group
-        # 2. open store with wanted sweep/group and merge with root
-
         if isinstance(filename_or_obj, io.IOBase):
             filename_or_obj.seek(0)
 
         store = NetCDF4DataStore.open(
             filename_or_obj,
             format=format,
-            group=None,
-            lock=False,
+            group=group,
+            lock=None,
         )
 
-        if group is not None:
-            variables = store.get_variables()
-            var = Dataset(variables)
-            site = {
-                key: loc
-                for key, loc in var.items()
-                if key in ["longitude", "latitude", "altitude"]
-            }
-            sweep_names = var.sweep_group_name.values
-            idx = np.where(sweep_names == group)
-            fixed_angle = var.sweep_fixed_angle.values[idx].item()
-
-            store.close()
-
-            if isinstance(filename_or_obj, io.IOBase):
-                filename_or_obj.seek(0)
-
-            store = NetCDF4DataStore.open(
-                filename_or_obj,
-                format=format,
-                group=group,
-                lock=False,
-            )
-
         store_entrypoint = StoreBackendEntrypoint()
 
-        ds = store_entrypoint.open_dataset(
-            store,
-            mask_and_scale=mask_and_scale,
-            decode_times=decode_times,
-            concat_characters=concat_characters,
-            decode_coords=decode_coords,
-            drop_variables=drop_variables,
-            use_cftime=use_cftime,
-            decode_timedelta=decode_timedelta,
-        )
+        with close_on_error(store):
+            ds = store_entrypoint.open_dataset(
+                store,
+                mask_and_scale=mask_and_scale,
+                decode_times=decode_times,
+                concat_characters=concat_characters,
+                decode_coords=decode_coords,
+                drop_variables=drop_variables,
+                use_cftime=use_cftime,
+                decode_timedelta=decode_timedelta,
+            )
 
         if group is not None:
-            ds = ds.assign_coords(site)
-            ds.attrs["fixed_angle"] = fixed_angle
             ds = _assign_data_radial2(ds)
             dim0 = list(set(ds.dims) & {"azimuth", "elevation"})[0]
             ds = ds.sortby(dim0)
@@ -1079,6 +1067,12 @@ class IrisStore(AbstractDataStore):
 class IrisBackendEntrypoint(BackendEntrypoint):
     """Xarray BackendEntrypoint for IRIS/Sigmet data."""
 
+    description = "Open IRIS/Sigmet files in Xarray"
+    url = (
+        "https://docs.wradlib.org/en/stable/notebooks/fileio/wradlib_iris_backend.html"
+    )
+    name = "wradlib-iris"
+
     def open_dataset(
         self,
         filename_or_obj,
@@ -1393,6 +1387,10 @@ class RainbowStore(AbstractDataStore):
 class RainbowBackendEntrypoint(BackendEntrypoint):
     """Xarray BackendEntrypoint for Rainbow5 data."""
 
+    description = "Open Rainbow5 files in Xarray"
+    url = "https://docs.wradlib.org/en/stable/notebooks/fileio/wradlib_rainbow_backend.html"
+    name = "wradlib-rainbow"
+
     def open_dataset(
         self,
         filename_or_obj,
@@ -1638,6 +1636,10 @@ class FurunoStore(AbstractDataStore):
 class FurunoBackendEntrypoint(BackendEntrypoint):
     """Xarray BackendEntrypoint for Furuno data."""
 
+    description = "Open FURUNO (.scn, .scnx) in Xarray"
+    url = "https://docs.wradlib.org/en/stable/notebooks/fileio/wradlib_furuno_backend.html"
+    name = "wradlib-furuno"
+
     def open_dataset(
         self,
         filename_or_obj,
